@@ -24,8 +24,8 @@ search_cb (GrlSource *source,
 
   if (media) {
     const gchar *title = grl_media_get_title (media);
-    if (GRL_IS_MEDIA_BOX (media)) {
-      guint childcount = grl_media_box_get_childcount (GRL_MEDIA_BOX (media));
+    if (grl_media_is_container (media)) {
+      guint childcount = grl_media_get_childcount (media);
       g_debug ("\t Got '%s' (container with %d elements)", title, childcount);
     } else {
       guint seconds = grl_media_get_duration (media);
@@ -92,7 +92,7 @@ load_plugins (void)
   registry = grl_registry_get_default ();
   g_signal_connect (registry, "source-added",
 		    G_CALLBACK (source_added_cb), NULL);
-  if (!grl_registry_load_all_plugins (registry, &error)) {
+  if (!grl_registry_load_all_plugins (registry, TRUE, &error)) {
     g_error ("Failed to load plugins: %s", error->message);
   }
 }
